@@ -8,6 +8,7 @@ from pathlib import Path
 import abc
 from functools import wraps
 import sys
+import re
 
 import luxem
 
@@ -174,7 +175,7 @@ class SnapPlugin(Plugin):
             out = set()
             for line in check_output(["snap", "list"]).decode("utf-8").splitlines()[1:]:
                 name = line.split()[0]
-                if name in ("core",):
+                if re.search("^core\\d*$", name):
                     continue
                 out.add(name)
             return out
